Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5)

Unified Diff: third_party/WebKit/Source/core/html/HTMLMediaElement.h

Issue 2068053002: Rename Blink constants generated from IDL files. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/html/HTMLMediaElement.h
diff --git a/third_party/WebKit/Source/core/html/HTMLMediaElement.h b/third_party/WebKit/Source/core/html/HTMLMediaElement.h
index c18c3c12bcb5c6c34aba09320651934eeccc4c62..2f3a19671a7d95acf03e75934ab6d60f3c330000 100644
--- a/third_party/WebKit/Source/core/html/HTMLMediaElement.h
+++ b/third_party/WebKit/Source/core/html/HTMLMediaElement.h
@@ -125,7 +125,7 @@ public:
void setSrcObject(MediaStreamDescriptor*);
MediaStreamDescriptor* getSrcObject() const { return m_srcObject.get(); }
- enum NetworkState { NETWORK_EMPTY, NETWORK_IDLE, NETWORK_LOADING, NETWORK_NO_SOURCE };
+ enum NetworkState { kNetworkEmpty, kNetworkIdle, kNetworkLoading, kNetworkNoSource };
NetworkState getNetworkState() const;
String preload() const;
@@ -139,7 +139,7 @@ public:
String canPlayType(const String& mimeType) const;
// ready state
- enum ReadyState { HAVE_NOTHING, HAVE_METADATA, HAVE_CURRENT_DATA, HAVE_FUTURE_DATA, HAVE_ENOUGH_DATA };
+ enum ReadyState { kHaveNothing, kHaveMetadata, kHaveCurrentData, kHaveFutureData, kHaveEnoughData };
ReadyState getReadyState() const;
bool seeking() const;
@@ -459,7 +459,7 @@ private:
void createPlaceholderTracksIfNecessary();
// Sets the selected/enabled tracks if they aren't set before we initially
- // transition to HAVE_METADATA.
+ // transition to kHaveMetadata.
void selectInitialTracksIfNecessary();
// Return true if and only if a user gesture is required to unlock this
@@ -570,7 +570,7 @@ private:
Member<HTMLMediaSource> m_mediaSource;
// Cached time value. Only valid when ready state is HAVE_METADATA or
// higher, otherwise the current time is assumed to be zero.
mutable double m_cachedTime;
« no previous file with comments | « third_party/WebKit/Source/core/html/HTMLFormElement.cpp ('k') | third_party/WebKit/Source/core/html/HTMLMediaElement.cpp » ('j') | no next file with comments »
@@ -570,7 +570,7 @@ private:
Member<HTMLMediaSource> m_mediaSource;
- // Cached time value. Only valid when ready state is HAVE_METADATA or
+ // Cached time value. Only valid when ready state is kHaveMetadata or
// higher, otherwise the current time is assumed to be zero.
mutable double m_cachedTime;

Powered by Google App Engine
This is Rietveld 408576698